import ConfigParser
from ideascaly.auth import AuthNonSSO
from ideascaly.api import API

config = ConfigParser.ConfigParser()
config.read('config')

community = config.get('example','community_url')
token = config.get('example','token')
member_id = 119793  # Replace with yours
img_file_name = 'pic.jpg'


# ---
# Create a new member
#
# Required parameters
# 'name': string containing the new member's name
# 'email': string containing the new member's email address
#
# Optional parameters
# 'silent': boolean indicating whether the creation of the member should be made without sending a verification email
# ---
def create_new_member(api):
    new_member = api.create_new_member(name="ideascaly_example", email="ideascaly-example@xyz.info")
    print('A new member with the id {} was created'.format(new_member.id))


# ---
# Get existing member's email address
#
# Required parameters
# 'memberId': integer containing the id of the member
# ---
def get_member_email(api):
    member = api.get_member_info_by_id(memberId=member_id)
    print('The member with the id {} has the email address {}'.format(member_id, member.email))


# ---
# Attach an image as a member's avatar
#
# Required parameters
# 'memberId': integer containing the id of the member
# 'filename': string containing the name of the file to attach
# ---
def attach_avatar_member(api):
    img = api.attach_avatar_to_member(filename=img_file_name, memberId=member_id)
    print('The avatar was successfully attached, the url of the attached image is {}'.format(img['url']))


if __name__ == '__main__':
    auth = AuthNonSSO(token)
    api = API(auth)
    api.community_url = community
    create_new_member(api)
    get_member_email(api)
    attach_avatar_member(api)




import ConfigParser
from ideascaly.auth import AuthNonSSO
from ideascaly.api import API

config = ConfigParser.ConfigParser()
config.read('config')

community = config.get('example','community_url')
token = config.get('example','token')
idea_id = 139718  # Replace with yours
myfile = 'pic.jpg'  # Replace with yours


# ---
# Attach a file to an idea
#
# Required parameters
# 'ideaId': integer of the id of the idea to which the file will be attached
# 'filename': string indicating the name of the file to be attached
#
# ---
def attach_file_idea(api):
    ret = api.attach_file_to_idea(filename=myfile,ideaId=idea_id)
    print('The file {} was attached to the idea with id {}'.format(myfile, ret.id))


if __name__ == '__main__':
    auth = AuthNonSSO(token)
    api = API(auth)
    api.community_url = community
    attach_file_idea(api)



import ConfigParser
from ideascaly.auth import AuthNonSSO
from ideascaly.api import API

config = ConfigParser.ConfigParser()
config.read('config')

community = config.get('example','community_url')
token = config.get('example','token')
idea_to_vote_id = 139718  # Replace with yours
idea_to_comment_id = 121848  # Replace with yours


# ---
# Vote up an idea
#
# Required parameters
# 'ideaId': integer of the id of the idea to be removed
#
# Optional parameters
# 'myVote': constant equal to 1 (indicate a positive vote)
# ---
def vote_up_idea(api):
    vote = api.vote_up_idea(ideaId=idea_to_vote_id)
    print('The idea {} was voted (id={}) up!'.format(idea_to_vote_id, vote.id))


# ---
# Vote down an idea
#
# Required parameters
# 'ideaId': integer of the id of the idea to be removed
#
# Optional parameters
# 'myVote': constant equal to -1 (indicate a negative vote)
# ---
def vote_down_idea(api):
    vote = api.vote_down_idea(ideaId=idea_to_vote_id)
    print('The idea {} was voted (id={}) down'.format(idea_to_vote_id, vote.id))


# ---
# Comment an idea
#
# Required parameters
# 'ideaId': integer of the id of the idea to be removed
# 'text': string containing the text of the comment
# ---
def comment_idea(api):
    comment = api.comment_idea(ideaId=idea_to_comment_id, text="This comment was placed from an example code!")
    print('The idea {} was commented (id={})'.format(idea_to_comment_id, comment.id))


if __name__ == '__main__':
    auth = AuthNonSSO(token)
    api = API(auth)
    api.community_url = community
    vote_up_idea(api)
    vote_down_idea(api)
    comment_idea(api)


import ConfigParser
from ideascaly.auth import AuthNonSSO
from ideascaly.api import API

config = ConfigParser.ConfigParser()
config.read('config')

community = config.get('example','community_url')
token = config.get('example','token')
campaign_id = 28416  # Replace with yours


# ---
# Create a new idea
#
# Required parameters
# 'title': string with the title of the idea (max 64 characters)
# 'text': string with the body of the idea
# 'campaignId': integer of the id of the campaign under which the idea will be posted
#
# Option parameters
# 'tags': list of words to label the idea
# 'custom fields': dictionary of defined custom fields
# ---
def create_new_idea(api):
    new_idea = api.create_idea(title='IdeaScaly Example', text='This is just an example', campaignId=campaign_id)
    print('The new idea was created successfully, its id is: {}'.format(new_idea.id))
    return new_idea.id


# ---
# Delete an idea
#
# Required parameters
# 'ideaId': integer of the id of the idea to be removed
# ---
def delete_idea(api, idea_id):
    deleted_idea = api.delete_idea(ideaId=idea_id)
    print('The idea {} was successfully removed'.format(deleted_idea.id))

if __name__ == '__main__':
    auth = AuthNonSSO(token)
    api = API(auth)
    api.community_url = community
    new_idea_id = create_new_idea(api)
    delete_idea(api, new_idea_id)






# IdeaScaly
# Copyright 2015 Jorge Saldivar
# See LICENSE for details.

import datetime
import mimetypes
import os
import six


from ideascaly.error import IdeaScalyError


def parse_datetime(long_ms):
    try:
        date_is = datetime.datetime.fromtimestamp(long_ms/1e3)
        return date_is
    except:
        return None


def parse_html_value(html):
    return html[html.find('>')+1:html.rfind('<')]


def parse_a_href(atag):
    start = atag.find('"') + 1
    end = atag.find('"', start)
    return atag[start:end]


def convert_to_utf8_str(arg):
    # written by Michael Norton (http://docondev.blogspot.com/)
    if isinstance(arg, six.text_type):
        arg = arg.encode('utf-8')
    elif not isinstance(arg, bytes):
        arg = six.text_type(arg).encode('utf-8')
    elif isinstance(arg, bytes):
        arg = arg.decode('utf-8')
    return arg


def import_simplejson():
    try:
        import simplejson as json
    except ImportError:
        try:
            import json  # Python 2.6+
        except ImportError:
            raise ImportError("Can't load a json library")

    return json


def pack_image(filename, max_size, form_field='image'):
        """Pack an image from file into multipart-formdata post body"""
        try:
            if os.path.getsize(filename) > (max_size * 1024):
                raise IdeaScalyError('File is too big, must be less than %skb.' % max_size)
        except os.error as e:
            raise IdeaScalyError('Unable to access file: %s' % e.strerror)

        # build the mulitpart-formdata body
        fp = open(filename, 'rb')

        # image must be gif, jpeg, or png
        file_type = mimetypes.guess_type(filename)
        if file_type is None:
            raise IdeaScalyError('Could not determine file type')
        file_type = file_type[0]
        if file_type not in ['image/gif', 'image/jpeg', 'image/png']:
            raise IdeaScalyError('Invalid file type for image: %s' % file_type)

        if isinstance(filename, six.text_type):
            filename = filename.encode('utf-8')

        BOUNDARY = b'Id34Sc4ly'
        body = list()
        body.append(b'--' + BOUNDARY)
        body.append('content-disposition: form-data; name="{0}";'
                    ' filename="{1}"'.format(form_field, filename)
                    .encode('utf-8'))
        body.append('content-type: {0}'.format(file_type).encode('utf-8'))
        body.append(b'')
        body.append(fp.read())
        body.append(b'--' + BOUNDARY + b'--')
        body.append(b'')
        fp.close()
        body = b'\r\n'.join(body)
        body_length = str(len(body))

        # build headers
        headers = {
            'content-type': 'multipart/form-data; boundary={0}'.format(BOUNDARY),
            'content-length': body_length
        }

        return headers, body